@@ -3,7 +3,7 @@ from .adda import ADDA
 from .aligner import RTN, Aligner
 from .base_adapter import BaseAdapter
 from .classifier import Classifier, Finetuner
-from .dann import DANN, GVB
-from .gan import CDAN, GAN, VADA, DomainConfusion
+from .dann import CDANNE, DANN, DANNE, GVB, GVBE
+from .gan import CDAN, CDANE, GAN, GANE, VADA, DomainConfusion
 from .mcd import MCD
 from .symnets import SymNets
