@@ -1,4 +1,5 @@
-from .base_container import BaseContainer, DeleteKey, KeyEnforcer
+from .base_container import BaseContainer, DeleteKey
+from .key_enforcer import KeyEnforcer
 from .lr_schedulers import LRSchedulers
 from .misc import Misc
 from .models import Models
