@@ -5,7 +5,7 @@ from ..utils import common_functions as c_f
 
 class ConcatDataset(torch.utils.data.ConcatDataset):
     """
-    Exactly the same as torch.utils.data.ConcatDataset
+    Exactly the same as ```torch.utils.data.ConcatDataset```
     except with a nice ```__repr__``` function.
     """
 
