@@ -1,12 +1,16 @@
 from .accuracy_validator import AccuracyValidator
 from .base_validator import BaseValidator
+from .class_cluster_validator import ClassClusterValidator
 from .deep_embedded_validator import DeepEmbeddedValidator
 from .diversity_validator import DiversityValidator
 from .entropy_validator import EntropyValidator
 from .error_validator import ErrorValidator
 from .im_validator import IMValidator
-
-# from .knn_validator import ClusterValidator, KNNValidator
+from .ist_validator import ISTValidator
+from .knn_validator import KNNValidator
+from .mmd_validator import MMDValidator
 from .multiple_validators import MultipleValidators
-from .silhouette_score_validator import SilhouetteScoreValidator
+from .per_class_validator import PerClassValidator
+from .score_history import ScoreHistories, ScoreHistory
 from .snd_validator import SNDValidator
+from .target_knn_validator import TargetKNNValidator
